pub struct Value(/* private fields */);Expand description
A single primitive value or a collection of values.
Implementations
Sourceimpl Value
impl Value
Sourcepub fn data_type(&self) -> ConstDataType
pub fn data_type(&self) -> ConstDataType
Get the data type of this Cassandra value
Sourcepub fn is_collection(&self) -> bool
pub fn is_collection(&self) -> bool
Returns true if a specified value is a collection.
Sourcepub fn get_set(&self) -> Result<SetIterator>
pub fn get_set(&self) -> Result<SetIterator>
Gets this value as a set iterator.
Sourcepub fn get_map(&self) -> Result<MapIterator>
pub fn get_map(&self) -> Result<MapIterator>
Gets this value as a map iterator.
Sourcepub fn get_user_type(&self) -> Result<UserTypeIterator>
pub fn get_user_type(&self) -> Result<UserTypeIterator>
Gets an iterator over the fields of the user type in this column or errors if you ask for the wrong type
Sourcepub fn get_string(&self) -> Result<String>
pub fn get_string(&self) -> Result<String>
Get this value as a string