SessionScope

Trait SessionScope 

pub trait SessionScope:
    Sealed
    + Clone
    + Send
    + Sync
    + 'static { }
The session scope defines if the session is bound session_scope::Bound, meaning it is associated with a keyspace. Or unbound session_scope::Unbound, meaning it is not associated with any keyspace.

Keyspace association is done by the connect and connect_lazy methods in Cluster.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors